import { CommonModule } from '@angular/common';
import { Component, Input, NgModule, Renderer2, ViewChild } from '@angular/core';

var NgxSlideshowComponent = (function () {
    /**
     * @param {?} renderer
     */
    function NgxSlideshowComponent(renderer) {
        this.renderer = renderer;
        this.cards = 1;
        this.padding = '14px';
        this.cardSize = '100%';
        this.resizeViewport = true;
        // Set initial index
        this.index = 0;
        this.min = -1;
        // To use with HammerJS
        this.SWIPE_ACTION = { LEFT: 'swipeleft', RIGHT: 'swiperight' };
    }
    /**
     * @return {?}
     */
    NgxSlideshowComponent.prototype.ngAfterViewInit = function () {
        this.onResize();
    };
    /**
     * @return {?}
     */
    NgxSlideshowComponent.prototype.ngOnChanges = function () {
        this.onResize();
    };
    /**
     * @return {?}
     */
    NgxSlideshowComponent.prototype.right = function () {
        this.rightBy(1);
    };
    /**
     * @return {?}
     */
    NgxSlideshowComponent.prototype.left = function () {
        this.leftBy(1);
    };
    /**
     * @param {?} i
     * @return {?}
     */
    NgxSlideshowComponent.prototype.goTo = function (i) {
        if (i > this.max || i < this.min) {
            throw new Error('goTo number on slideshow is out of bounds');
        }
        else {
            this.index = i;
            this.setLeft();
        }
    };
    /**
     * @param {?} i
     * @return {?}
     */
    NgxSlideshowComponent.prototype.leftBy = function (i) {
        this.index = this.calc(this.index - i);
        this.setLeft();
    };
    /**
     * @param {?} i
     * @return {?}
     */
    NgxSlideshowComponent.prototype.rightBy = function (i) {
        this.index = this.calc(this.index + i);
        this.setLeft();
    };
    /**
     * @param {?} newIndex
     * @return {?}
     */
    NgxSlideshowComponent.prototype.calc = function (newIndex) {
        if (this.max <= newIndex) {
            return this.calc(newIndex - this.max);
        }
        else if (this.min >= newIndex) {
            return this.calc(this.max + newIndex);
        }
        else {
            return newIndex;
        }
    };
    /**
     * @return {?}
     */
    NgxSlideshowComponent.prototype.setLeft = function () {
        var /** @type {?} */ newSize = "calc(0px - calc(calc(" + this.trueCardSize + " + " + this.truePaddingSize + ") * " + this.index + "))";
        this.renderer.setStyle(this.slides.nativeElement, 'left', newSize);
    };
    /**
     * @param {?=} action
     * @return {?}
     */
    NgxSlideshowComponent.prototype.swipe = function (action) {
        if (action === void 0) { action = this.SWIPE_ACTION.RIGHT; }
        if (action === this.SWIPE_ACTION.RIGHT) {
            this.left();
        }
        if (action === this.SWIPE_ACTION.LEFT) {
            this.right();
        }
    };
    /**
     * @param {?} str
     * @param {?} searchStr
     * @return {?}
     */
    NgxSlideshowComponent.prototype.endsWith = function (str, searchStr) {
        return str.substr(str.length - searchStr.length, searchStr.length) === searchStr;
    };
    
    /**
     * @return {?}
     */
    NgxSlideshowComponent.prototype.onResize = function () {
        var /** @type {?} */ cardObjs = this.slides.nativeElement.getElementsByTagName('li'); // Get list of objects
        var /** @type {?} */ numCards = cardObjs.length; // Find out how many cards there are
        this.max = (numCards - this.cards) + 1; // Calculate max: # cards you see on screen - full # of cards
        if (!this.resizeViewport) {
            this.viewSize = this.viewport.nativeElement.offsetWidth;
        }
        // Gets card size based on viewport (to calculate % based sizes)
        if (this.cardSize.includes('%') && this.resizeViewport) {
            this.renderer.setStyle(this.viewport.nativeElement, 'width', this.cardSize);
            this.trueCardSize = this.viewport.nativeElement.offsetWidth + "px";
        }
        else if (this.endsWith(this.cardSize, '%') && !this.resizeViewport) {
            // TODO: Support entries such as calc(20% - 5px) using regex instead of cruddy endsWith
            // TODO: Add tests for all unit types such as this
            var /** @type {?} */ cardPercentage = (Number(this.cardSize.slice(0, -1)) / 100); // Turn into decimal to do math
            this.trueCardSize = this.viewSize * cardPercentage + "px";
        }
        else {
            this.trueCardSize = this.cardSize;
        }
        // Gets card size based on viewport (to calculate % based sizes)
        if (this.padding.includes('%') && this.resizeViewport) {
            this.renderer.setStyle(this.viewport.nativeElement, 'width', this.padding);
            this.truePaddingSize = this.viewport.nativeElement.offsetWidth + "px";
        }
        else if (this.endsWith(this.padding, '%') && !this.resizeViewport) {
            var /** @type {?} */ cardPercentage = (Number(this.cardSize.slice(0, -1)) / 100); // Turn into decimal to do math
            this.truePaddingSize = this.viewSize * cardPercentage + "px";
        }
        else {
            this.truePaddingSize = this.padding;
        }
        // Set size of cards + padding for calculating slides div and viewport div
        var /** @type {?} */ fullCardSize = "calc(" + this.trueCardSize + " + " + this.truePaddingSize + ")";
        // This is how wide the viewport will be
        if (this.resizeViewport) {
            this.renderer.setStyle(this.viewport.nativeElement, 'width', "calc(" + fullCardSize + " * " + this.cards + ")");
        }
        // This sets slides to be exactly the width needed for the cards on screen
        this.renderer.setStyle(this.slides.nativeElement, 'width', "calc(" + fullCardSize + " * " + numCards + ")");
        // Set size of cards. Wish this could be class based, but alas not
        for (var /** @type {?} */ i = 0; i < numCards; i++) {
            this.renderer.setStyle(cardObjs[i], 'width', "" + this.trueCardSize);
            this.renderer.setStyle(cardObjs[i], 'margin', "0 calc(" + this.truePaddingSize + " / 2)");
        }
        this.setLeft();
    };
    return NgxSlideshowComponent;
}());
NgxSlideshowComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngx-slideshow',
                template: "\n    <div #viewport id=\"viewport\" class=\"ngx-slideshow-component viewport\" [class.full-width]=\"!resizeViewport\"\n         (window:resize)=\"onResize()\">\n      <ul #slides id=\"slides\" class=\"slides no-wrap row\" style=\"left: 0;\">\n        <ng-content select=\"li\"></ng-content>\n      </ul>\n    </div>\n  ",
                styles: ["\n    .ngx-slideshow-component.viewport{display:inline-block;overflow:hidden}.ngx-slideshow-component.viewport.full-width{width:100%}.ngx-slideshow-component.viewport .slides{transition:all 1s ease;position:relative;white-space:nowrap;padding:0;margin:0}.ngx-slideshow-component.viewport ::ng-deep .slides>li{position:relative;float:left;list-style:none}\n  "]
            },] },
];
/**
 * @nocollapse
 */
NgxSlideshowComponent.ctorParameters = function () { return [
    { type: Renderer2, },
]; };
NgxSlideshowComponent.propDecorators = {
    'cards': [{ type: Input },],
    'padding': [{ type: Input },],
    'cardSize': [{ type: Input },],
    'resizeViewport': [{ type: Input },],
    'viewport': [{ type: ViewChild, args: ['viewport',] },],
    'slides': [{ type: ViewChild, args: ['slides',] },],
};

var NgxSlideshowModule = (function () {
    function NgxSlideshowModule() {
    }
    /**
     * @return {?}
     */
    NgxSlideshowModule.forRoot = function () {
        return {
            ngModule: NgxSlideshowModule,
            providers: []
        };
    };
    return NgxSlideshowModule;
}());
NgxSlideshowModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                exports: [NgxSlideshowComponent],
                declarations: [NgxSlideshowComponent]
            },] },
];
/**
 * @nocollapse
 */
NgxSlideshowModule.ctorParameters = function () { return []; };

/**
 * Generated bundle index. Do not edit.
 */

export { NgxSlideshowComponent, NgxSlideshowModule };
//# sourceMappingURL=ngx-slideshow.es5.js.map
